# Select Host to change

- Update all hosts
- Recover deleted Hosts
- Add Host

2 results ( 4 total )
MockedCsrfTokenNode
Action:
0 of 2 selected

| Name | WAN access | 1 Last Status | 2 Last update | IP (v4) | Mac | Create date
--- | --- | --- | --- | --- | --- | --- | ---
| unique_name2 | unknown |  | Jan. 1, 2000, 1:02 a.m. | - | AB:CD:EF:12:00:02 | Jan. 1, 2000, 1:02 a.m.
| unique_name1 | unknown |  | Jan. 1, 2000, 1:01 a.m. | - | AB:CD:EF:12:00:01 | Jan. 1, 2000, 1:01 a.m.

2 Hosts

## Filter

### ✖ Clear all filters

By Last Status

- All
- Yes
- No

By WAN access

- All
- granted
- denied
- error
- unknown

By Interface Type

- All
- -

By Address Source

- All
- DHCP

By unique name

- All
- Yes
- No